@@ -13,9 +13,8 @@ Used to generate an OpenAPI schema.
 from dataclasses import dataclass
 from typing import Optional
 
-from fastapi.params import Form
-
 from aioauth.types import GrantType, TokenType
+from fastapi.params import Form
 
 
 @dataclass
@@ -36,4 +35,4 @@ class TokenForm:
 @dataclass
 class TokenIntrospectForm:
     token: Optional[str] = Form(None)
-    token_type: Optional[TokenType] = Form(None)
+    token_type_hint: Optional[TokenType] = Form(None)
